==> mlr3spatiotempcv_0.1.0.tar.gz: mlr3spatiotempcv/R/bibentries.R <==
#' @importFrom utils bibentry
bibentries = c( # nolint start
  brenning2012 = bibentry("inproceedings",
    doi = "10.1109/igarss.2012.6352393",
    year = "2012",
    month = "jul",
    publisher = "IEEE",
    author = "Alexander Brenning",
    title = "Spatial cross-validation and bootstrap for the assessment of prediction rules in remote sensing: The R package sperrorest",
    booktitle = "2012 {IEEE} International Geoscience and Remote Sensing Symposium"
  ),

  valavi2018 = bibentry("article",
    doi = "10.1101/357798",
    year = "2018",
    journal = "bioRxiv",
    month = "jun",
    publisher = "Cold Spring Harbor Laboratory",
    author = "Roozbeh Valavi and Jane Elith and Jose J. Lahoz-Monfort and Gurutzeta Guillera-Arroita",
    title = "blockCV: an R package for generating spatially or environmentally separated folds for k-fold cross-validation of species distribution models"
  ),

  schratz2019 = bibentry("article",
    doi = "10.1016/j.ecolmodel.2019.06.002",
    year = "2019",
    month = "aug",
    publisher = "Elsevier {BV}",
    volume = "406",
    pages = "109--120",
    author = "Patrick Schratz and Jannes Muenchow and Eugenia Iturritxa and Jakob Richter and Alexander Brenning",
    title = "Hyperparameter tuning and performance assessment of statistical and machine-learning algorithms using spatial data",
    journal = "Ecological Modelling"
  ),

  burman1994 = bibentry("article",
    doi = "10.1093/biomet/81.2.351",
    year = "1994",
    publisher = "Oxford University Press ({OUP})",
    volume = "81",
    number = "2",
    pages = "351--358",
    author = "Prabir Burman and Edmond Chow and Deborah Nolan",
    title = "A cross-validatory method for dependent data",
    journal = "Biometrika"
  ),

  cliff1970 = bibentry("article",
    doi = "10.2307/143144",
    year = "1970",
    month = "jun",
    publisher = "JSTOR",
    volume = "46",
    pages = "269",
    author = "Andrew D. Cliff and Keith Ord",
    title = "Spatial Autocorrelation: A Review of Existing and New Measures with Applications",
    journal = "Economic Geography"
  ),

  racine2000 = bibentry("article",
    doi = "10.1016/s0304-4076(00)00030-0",
    year = "2000",
    month = "nov",
    publisher = "Elsevier {BV}",
    volume = "99",
    number = "1",
    pages = "39--61",
    author = "Jeff Racine",
    title = "Consistent cross-validatory model-selection for dependent data: hv-block cross-validation",
    journal = "Journal of Econometrics"
  ),

  lovelace_geocomputation_2019 = bibentry("book",
    address = "Boca Raton; London; New York",
    edition = "1st ed.",
    series = "The {R} {Series}",
    title = "Geocomputation with {R}",
    isbn = "1-138-30451-4",
    publisher = "Chapman and Hall/CRC. https://geocompr.robinlovelace.net/",
    author = "Lovelace, Robin and Nowosad, Jakub and Muenchow, Jannes",
    year = "2019"
  ),

  brenning_landslide_2015 = bibentry("article",
    title = "Landslide susceptibility near highways is increased by 1 order of magnitude in the Andes of southern Ecuador, Loja province",
    author = "Brenning, A and Schwinn, M and Ruiz-P\u00e1ez, AP and Muenchow, J",
    journal = "Natural Hazards & Earth System Sciences",
    volume = "15",
    number = "1",
    year = "2015"
  ),

  meyer2018 = bibentry("article",
    doi = "10.1016/j.envsoft.2017.12.001",
    url = "https://doi.org/10.1016%2Fj.envsoft.2017.12.001",
    year = "2018",
    month = "mar",
    publisher = "Elsevier {BV}",
    volume = "101",
    pages = "1--9",
    author = "Hanna Meyer and Christoph Reudenbach and Tomislav Hengl and Marwan Katurji and Thomas Nauss",
    title = "Improving performance of spatio-temporal machine learning models using forward feature selection and target-oriented validation",
    journal = "Environmental Modelling & Software"
  ),

  zhao2002 = bibentry("article",
    url = "http://glaros.dtc.umn.edu/gkhome/node/167",
    year = "2002",
    pages = "51-524",
    author = "Ying Zhao and George Karypis",
    title = "Evaluation of Hierarchical Clustering Algorithms for Document Datasets",
    journal = "11th Conference of Information and Knowledge Management (CIKM)"
  )
) # nolint end

==> mlr3spatiotempcv_0.1.1.tar.gz: mlr3spatiotempcv/R/bibentries.R <==
# nocov start
format_bib = function(...) {
  str = vapply(list(...), function(entry) tools::toRd(bibentries[[entry]]), FUN.VALUE = "")
  paste0(str, collapse = "\n\n")
}

#' @importFrom utils bibentry
bibentries = c( # nolint start
  brenning2012 = bibentry("inproceedings",
    doi = "10.1109/igarss.2012.6352393",
    year = "2012",
    month = "jul",
    publisher = "IEEE",
    author = "Alexander Brenning",
    title = "Spatial cross-validation and bootstrap for the assessment of prediction rules in remote sensing: The R package sperrorest",
    booktitle = "2012 {IEEE} International Geoscience and Remote Sensing Symposium"
  ),

  valavi2018 = bibentry("article",
    doi = "10.1101/357798",
    year = "2018",
    journal = "bioRxiv",
    month = "jun",
    publisher = "Cold Spring Harbor Laboratory",
    author = "Roozbeh Valavi and Jane Elith and Jose J. Lahoz-Monfort and Gurutzeta Guillera-Arroita",
    title = "blockCV: an R package for generating spatially or environmentally separated folds for k-fold cross-validation of species distribution models"
  ),

  schratz2019 = bibentry("article",
    doi = "10.1016/j.ecolmodel.2019.06.002",
    year = "2019",
    month = "aug",
    publisher = "Elsevier {BV}",
    volume = "406",
    pages = "109--120",
    author = "Patrick Schratz and Jannes Muenchow and Eugenia Iturritxa and Jakob Richter and Alexander Brenning",
    title = "Hyperparameter tuning and performance assessment of statistical and machine-learning algorithms using spatial data",
    journal = "Ecological Modelling"
  ),

  burman1994 = bibentry("article",
    doi = "10.1093/biomet/81.2.351",
    year = "1994",
    publisher = "Oxford University Press ({OUP})",
    volume = "81",
    number = "2",
    pages = "351--358",
    author = "Prabir Burman and Edmond Chow and Deborah Nolan",
    title = "A cross-validatory method for dependent data",
    journal = "Biometrika"
  ),

  cliff1970 = bibentry("article",
    doi = "10.2307/143144",
    year = "1970",
    month = "jun",
    publisher = "JSTOR",
    volume = "46",
    pages = "269",
    author = "Andrew D. Cliff and Keith Ord",
    title = "Spatial Autocorrelation: A Review of Existing and New Measures with Applications",
    journal = "Economic Geography"
  ),

  racine2000 = bibentry("article",
    doi = "10.1016/s0304-4076(00)00030-0",
    year = "2000",
    month = "nov",
    publisher = "Elsevier {BV}",
    volume = "99",
    number = "1",
    pages = "39--61",
    author = "Jeff Racine",
    title = "Consistent cross-validatory model-selection for dependent data: hv-block cross-validation",
    journal = "Journal of Econometrics"
  ),

  lovelace_geocomputation_2019 = bibentry("book",
    address = "Boca Raton; London; New York",
    edition = "1st ed.",
    series = "The {R} {Series}",
    title = "Geocomputation with {R}",
    isbn = "1-138-30451-4",
    publisher = "Chapman and Hall/CRC. https://geocompr.robinlovelace.net/",
    author = "Lovelace, Robin and Nowosad, Jakub and Muenchow, Jannes",
    year = "2019"
  ),

  brenning_landslide_2015 = bibentry("article",
    title = "Landslide susceptibility near highways is increased by 1 order of magnitude in the Andes of southern Ecuador, Loja province",
    author = "Brenning, A and Schwinn, M and Ruiz-P\u00e1ez, AP and Muenchow, J",
    journal = "Natural Hazards & Earth System Sciences",
    volume = "15",
    number = "1",
    year = "2015"
  ),

  meyer2018 = bibentry("article",
    doi = "10.1016/j.envsoft.2017.12.001",
    year = "2018",
    month = "mar",
    publisher = "Elsevier {BV}",
    volume = "101",
    pages = "1--9",
    author = "Hanna Meyer and Christoph Reudenbach and Tomislav Hengl and Marwan Katurji and Thomas Nauss",
    title = "Improving performance of spatio-temporal machine learning models using forward feature selection and target-oriented validation",
    journal = "Environmental Modelling & Software"
  ),

  zhao2002 = bibentry("article",
    url = "http://glaros.dtc.umn.edu/gkhome/node/167",
    year = "2002",
    pages = "51-524",
    author = "Ying Zhao and George Karypis",
    title = "Evaluation of Hierarchical Clustering Algorithms for Document Datasets",
    journal = "11th Conference of Information and Knowledge Management (CIKM)"
  )
) # nolint end
# nocov end
